#!/bin/sh
# init-functions tests

NAME=test-daemon
DAEMON=/usr/lib/ci-tests/lsb/$NAME
PIDFILE=/var/run/$NAME.pid
PASSMSG="[Passed]"
FAILMSG="[FAIL!]"

. /lib/lsb/init-functions

#Check that no other instances are running
if [ $(pidof test-daemon) ] 
then 
	log_warning_msg "test-daemon already running"
	log_warning_msg "Killing all instances"
	killall test-daemon
	sleep 1
fi
rm $PIDFILE > /dev/null 2>&1

#Check that status_of_proc returns 'not running'
log_progress_msg "Test that status_of_proc returns not running"
if ( status_of_proc $DAEMON > /dev/null)
then
	log_failure_msg "Failed: status_of_proc shows running process"
	return 1
else	
	log_success_msg "$PASSMSG"
fi

#Start a daemon
start_daemon -p /var/run/test-daemon.pid $DAEMON &
log_progress_msg "Started daemon"
sleep 1

# Get pid of daemon
pid=$(pidofproc $DAEMON)

#Check by pid that the daemon has been started
if [ "$pid" ]
then 
	log_success_msg "..running"
else
	log_failure_msg "Daemon wasn't started."
	return 1
fi

log_progress_msg "Test status_of_proc of running daemon"
if ( status_of_proc $DAEMON > /dev/null )
then
	log_success_msg "$PASSMSG"	
else	
	log_failure_msg "$FAILMSG"
	return 1
fi

log_progress_msg "pidofproc test: "
if pidofproc test-daemon >/dev/null -neq $PID 
then
	log_success_msg "$PASSMSG"
else	
	log_failure_msg "$FAILMSG"
	return 1
fi